# TODO

-   Add an xlsx dialect that only creates tabs for sets with
    cards present in the collection
-   Group sets by parent set is xlsx output?
    -   Block? probably not
-   diffs to stdout
-   Update card_count for sets when processing bundle filters
-   Can we read images from icon_svg_uri in sets, rasterize, and
    insert the set icons in the xlsx "All Sets" page?
-   Can we switch to hatchling as our build system?
